
Feeling down today? Generate a Random Compliment usingt his tool.

- Thanks to [grantcodes/complimentr](https://github.com/grantcodes/complimenter) for the js library. The code is ported to python.

## INSTALL

```python
pip install compliment
```

## EXAMPLES

```python
from compliment import Compliment
c = Compliment()
c.make_compliment()
```
or using a one liner.

```python
print(Compliment().make_compliment())
```
